@@ -1,10 +1,12 @@
 (* Mathematica Init File *)
 
-Print["For help, use the ", 
+Print["Version: 1.1 ; Author: Renato Fonseca\nFor help, use the ", 
  Hyperlink["Susyno Tutorial", 
   "paclet:Susyno/tutorial/SusynoTutorial"], " and the built-in \
 documentation."]
 
+
+ClearAll["`*"];
 Get[ "Susyno`LieGroups`"]
 Get[ "Susyno`SusyRGEs`"]
-Get[ "Susyno`Susyno`"]
\ No newline at end of file
+Get[ "Susyno`Susyno`"]
